<?php

/**
 * @file
 * Drush extension for myDropWizard module.
 */

function mydropwizard_drush_command() {
  return array(
    'mydropwizard-list-projects' => array(
      'description' => 'Outputs the list of enabled projects on this site.',
      'options' => array(
        'branch-only' => 'Only output the major branch version - not the full version string',
        'header-row' => 'Add a header row for use with --format=csv',
      ),
      'outputformat' => array(
        'default' => 'table',
        'pipe-format' => 'csv',
        'field-labels' => array('project' => 'Project', 'version' => 'Version'),
        'fields-default' => array('project', 'version'),
        'output-data-type' => 'format-table',
      ),
    ),
  );
}

function drush_mydropwizard_list_projects() {
  $module_list = \Drupal::service('extension.list.module')->reset()->getList();
  $theme_list = \Drupal::service('extension.list.theme')->reset()->getList();

  $project_data = \Drupal::service('mydropwizard.vitals_sender')->gatherProjectData($module_list, $theme_list);

  $data = [];
  if (drush_get_option('header-row')) {
    $data[] = array(
      'project' => 'Project',
      'version' => 'Version',
    );
  }

  foreach ($project_data as $project) {
    $name = $project['name'];
    $version = $project['value'];

    // Switch to only major branch version.
    if (drush_get_option('branch-only')) {
      // Extract the major version part.
      if (preg_match('/^(\d+)/', $version, $matches)) {
        $version = $matches[1];
      }
      else {
        $version = '0';
      }
    }

    $data[] = array(
      'project' => $name,
      'version' => $version,
    );
  }

  return $data;
}

