<?php

namespace Drupal\mydropwizard\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\mydropwizard\MydropwizardVitalsSender;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Response;

/**
 * Controller for myDropWizard's agent endpoints.
 */
class MydropwizardController extends ControllerBase {

  /**
   * @var \Drupal\mydropwizard\MydropwizardVitalsSender
   */
  protected $vitalsSender;

  /**
   * MydropwizardController constructor.
   *
   * @param \Drupal\mydropwizard\MydropwizardVitalsSender $vitals_sender
   *   The vitals sender service.
   */
  public function __construct(MydropwizardVitalsSender $vitals_sender) {
    $this->vitalsSender = $vitals_sender;
  }

  /**
   * {@inheritDoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('mydropwizard.vitals_sender')
    );
  }

  /**
   * Requests that this site send its vitals to mydropwizard.
   */
  public function requestVitals() {
    $payload_id = \Drupal::request()->request->get('payload_id');
    if (empty($payload_id)) {
      return new Response('Bad request', 400);
    }

    $rebuild = \Drupal::request()->request->get('no_rebuild');
    $this->vitalsSender->sendVitalsData($payload_id, empty($rebuild));

    return new Response('Ok', 200);
  }

}
