<?php

namespace Drupal\mydropwizard\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Settings form for mydropwizard module.
 */
class MydropwizardSettingsForm extends ConfigFormBase {

  /**
   * Config object name.
   *
   * @var string
   */
  const SETTINGS = 'mydropwizard.settings';

  /**
   * {@inheritDoc}
   */
  public function getFormId() {
    return 'mydropwizard_admin_settings';
  }

  /**
   * {@inheritDoc}
   */
  protected function getEditableConfigNames() {
    return [ static::SETTINGS ];
  }

  /**
   * {@inheritDoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(static::SETTINGS);

    $form['username'] = [
      '#title' => $this->t('Username'),
      '#type' => 'textfield',
      '#default_value' => $config->get('username'),
    ];

    $form['api_key'] = [
      '#title' => $this->t('API key'),
      '#type' => 'password',
      '#default_value' => $config->get('api_key'),
    ];

    $form['submission_mode'] = [
      '#title' => $this->t('Submission mode'),
      '#type' => 'radios',
      '#options' => [
        'pull' => $this->t('Pull'),
        'push' => $this->t('Push'),
      ],
      '#description' => $this->t("Most sites use <em>Pull</em>; the <em>Push</em> mode is only necessary if the site isn't publicly accessible and requires a special support plan."),
      '#default_value' => $config->get('submission_mode'),
    ];

    $form['site_id'] = [
      '#title' => $this->t('Site ID'),
      '#type' => 'textfield',
      '#states' => [
        'visible' => [
          ':input[name="submission_mode"]' => array('value' => 'push'),
        ],
      ],
      '#description' => $this->t("The site ID in myDropWizard's system. Only necessary for sites using the <em>Push</em> submission mode."),
      '#default_value' => $config->get('site_id'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritDoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->configFactory->getEditable(static::SETTINGS)
      ->set('username', $form_state->getValue('username'))
      ->set('submission_mode', $form_state->getValue('submission_mode'))
      ->set('site_id', $form_state->getValue('site_id'));

    $api_key = $form_state->getValue('api_key');
    if ($api_key !== '') {
      $config->set('api_key', $api_key);
    }

    $config->save();

    parent::submitForm($form, $form_state);
  }

}
